@@ -26,6 +26,13 @@ BACKENDS = (
 #: details on the format.
 CONSOLE_LOG_FORMAT = u'%(levelname)-8s %(message)s'
 
+#: Which GStreamer bin description to use in :class:`mopidy.outputs.CustomOutput`.
+#:
+#: Default::
+#:
+#:     CUSTOM_OUTPUT = u'fakesink'
+CUSTOM_OUTPUT = u'fakesink'
+
 #: The log format used for debug logging.
 #:
 #: See http://docs.python.org/library/logging.html#formatter-objects for
@@ -54,13 +61,6 @@ FRONTENDS = (
     u'mopidy.frontends.lastfm.LastfmFrontend',
 )
 
-#: Which GStreamer audio sink to use in :mod:`mopidy.outputs.gstreamer`.
-#:
-#: Default::
-#:
-#:     GSTREAMER_AUDIO_SINK = u'autoaudiosink'
-GSTREAMER_AUDIO_SINK = u'autoaudiosink'
-
 #: Your `Last.fm <http://www.last.fm/>`_ username.
 #:
 #: Used by :mod:`mopidy.frontends.lastfm`.
@@ -143,13 +143,6 @@ MIXER_EXT_SPEAKERS_B = None
 #:     MIXER_MAX_VOLUME = 100
 MIXER_MAX_VOLUME = 100
 
-#: Audio output handler to use.
-#:
-#: Default::
-#:
-#:     OUTPUT = u'mopidy.outputs.gstreamer.GStreamerOutput'
-OUTPUT = u'mopidy.outputs.gstreamer.GStreamerOutput'
-
 #: Which address Mopidy's MPD server should bind to.
 #:
 #:Examples:
@@ -164,15 +157,81 @@ OUTPUT = u'mopidy.outputs.gstreamer.GStreamerOutput'
 #:     Listens on all interfaces, both IPv4 and IPv6.
 MPD_SERVER_HOSTNAME = u'127.0.0.1'
 
+#: Which TCP port Mopidy's MPD server should listen to.
+#:
+#: Default: 6600
+MPD_SERVER_PORT = 6600
+
 #: The password required for connecting to the MPD server.
 #:
 #: Default: :class:`None`, which means no password required.
 MPD_SERVER_PASSWORD = None
 
-#: Which TCP port Mopidy's MPD server should listen to.
+#: List of outputs to use. See :mod:`mopidy.outputs` for all available
+#: backends
 #:
-#: Default: 6600
-MPD_SERVER_PORT = 6600
+#: Default::
+#:
+#:     OUTPUTS = (
+#:         u'mopidy.outputs.local.LocalOutput',
+#:     )
+OUTPUTS = (
+    u'mopidy.outputs.local.LocalOutput',
+)
+
+#: Hostname of the SHOUTcast server which Mopidy should stream audio to.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:    SHOUTCAST_OUTPUT_HOSTNAME = u'127.0.0.1'
+SHOUTCAST_OUTPUT_HOSTNAME = u'127.0.0.1'
+
+#: Port of the SHOUTcast server.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:    SHOUTCAST_OUTPUT_PORT = 8000
+SHOUTCAST_OUTPUT_PORT = 8000
+
+#: User to authenticate as against SHOUTcast server.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:    SHOUTCAST_OUTPUT_USERNAME = u'source'
+SHOUTCAST_OUTPUT_USERNAME = u'source'
+
+#: Password to authenticate with against SHOUTcast server.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:    SHOUTCAST_OUTPUT_PASSWORD = u'hackme'
+SHOUTCAST_OUTPUT_PASSWORD = u'hackme'
+
+#: Mountpoint to use for the stream on the SHOUTcast server.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:    SHOUTCAST_OUTPUT_MOUNT = u'/stream'
+SHOUTCAST_OUTPUT_MOUNT = u'/stream'
+
+#: Encoder to use to process audio data before streaming to SHOUTcast server.
+#:
+#: Used by :mod:`mopidy.outputs.shoutcast`.
+#:
+#: Default::
+#:
+#:     SHOUTCAST_OUTPUT_ENCODER = u'lame mode=stereo bitrate=320'
+SHOUTCAST_OUTPUT_ENCODER = u'lame mode=stereo bitrate=320'
 
 #: Path to the Spotify cache.
 #:
@@ -189,11 +248,13 @@ SPOTIFY_USERNAME = u''
 #: Used by :mod:`mopidy.backends.spotify`.
 SPOTIFY_PASSWORD = u''
 
-#: Do you prefer high bitrate (320k)?
+#: Spotify preferred bitrate.
+#:
+#: Available values are 96, 160, and 320.
 #:
 #: Used by :mod:`mopidy.backends.spotify`.
 #
 #: Default::
 #:
-#:     SPOTIFY_HIGH_BITRATE = False # 160k
-SPOTIFY_HIGH_BITRATE = False
+#:     SPOTIFY_BITRATE = 160
+SPOTIFY_BITRATE = 160
