@@ -8,26 +8,26 @@ from mopidy.utils.path import path_to_uri
 from mopidy.backends.local.translator import parse_m3u, parse_mpd_tag_cache
 from mopidy.models import Track, Artist, Album
 
-from tests import SkipTest, data_folder
+from tests import SkipTest, path_to_data_dir
 
-song1_path = data_folder('song1.mp3')
-song2_path = data_folder('song2.mp3')
-encoded_path = data_folder(u'æøå.mp3')
+song1_path = path_to_data_dir('song1.mp3')
+song2_path = path_to_data_dir('song2.mp3')
+encoded_path = path_to_data_dir(u'æøå.mp3')
 song1_uri = path_to_uri(song1_path)
 song2_uri = path_to_uri(song2_path)
 encoded_uri = path_to_uri(encoded_path)
 
 class M3UToUriTest(unittest.TestCase):
     def test_empty_file(self):
-        uris = parse_m3u(data_folder('empty.m3u'))
+        uris = parse_m3u(path_to_data_dir('empty.m3u'))
         self.assertEqual([], uris)
 
     def test_basic_file(self):
-        uris = parse_m3u(data_folder('one.m3u'))
+        uris = parse_m3u(path_to_data_dir('one.m3u'))
         self.assertEqual([song1_uri], uris)
 
     def test_file_with_comment(self):
-        uris = parse_m3u(data_folder('comment.m3u'))
+        uris = parse_m3u(path_to_data_dir('comment.m3u'))
         self.assertEqual([song1_uri], uris)
 
     def test_file_with_absolute_files(self):
@@ -64,11 +64,11 @@ class M3UToUriTest(unittest.TestCase):
                 os.remove(tmp.name)
 
     def test_encoding_is_latin1(self):
-        uris = parse_m3u(data_folder('encoding.m3u'))
+        uris = parse_m3u(path_to_data_dir('encoding.m3u'))
         self.assertEqual([encoded_uri], uris)
 
     def test_open_missing_file(self):
-        uris = parse_m3u(data_folder('non-existant.m3u'))
+        uris = parse_m3u(path_to_data_dir('non-existant.m3u'))
         self.assertEqual([], uris)
 
 
@@ -81,7 +81,7 @@ expected_albums = [Album(name='albumname', artists=expected_artists,
 expected_tracks = []
 
 def generate_track(path, ident):
-    uri = path_to_uri(data_folder(path))
+    uri = path_to_uri(path_to_data_dir(path))
     track = Track(name='trackname', artists=expected_artists, track_no=1,
         album=expected_albums[0], length=4000, uri=uri)
     expected_tracks.append(track)
@@ -98,28 +98,28 @@ generate_track('subdir1/subsubdir/song9.mp3', 1)
 
 class MPDTagCacheToTracksTest(unittest.TestCase):
     def test_emtpy_cache(self):
-        tracks = parse_mpd_tag_cache(data_folder('empty_tag_cache'),
-            data_folder(''))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('empty_tag_cache'),
+            path_to_data_dir(''))
         self.assertEqual(set(), tracks)
 
     def test_simple_cache(self):
-        tracks = parse_mpd_tag_cache(data_folder('simple_tag_cache'),
-            data_folder(''))
-        uri = path_to_uri(data_folder('song1.mp3'))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('simple_tag_cache'),
+            path_to_data_dir(''))
+        uri = path_to_uri(path_to_data_dir('song1.mp3'))
         track = Track(name='trackname', artists=expected_artists, track_no=1,
             album=expected_albums[0], length=4000, uri=uri)
         self.assertEqual(set([track]), tracks)
 
     def test_advanced_cache(self):
-        tracks = parse_mpd_tag_cache(data_folder('advanced_tag_cache'),
-             data_folder(''))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('advanced_tag_cache'),
+             path_to_data_dir(''))
         self.assertEqual(set(expected_tracks), tracks)
 
     def test_unicode_cache(self):
-        tracks = parse_mpd_tag_cache(data_folder('utf8_tag_cache'),
-             data_folder(''))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('utf8_tag_cache'),
+             path_to_data_dir(''))
 
-        uri = path_to_uri(data_folder('song1.mp3'))
+        uri = path_to_uri(path_to_data_dir('song1.mp3'))
         artists = [Artist(name=u'æøå')]
         album = Album(name=u'æøå', artists=artists)
         track = Track(uri=uri, name=u'æøå', artists=artists,
@@ -132,14 +132,14 @@ class MPDTagCacheToTracksTest(unittest.TestCase):
         raise SkipTest
 
     def test_cache_with_blank_track_info(self):
-        tracks = parse_mpd_tag_cache(data_folder('blank_tag_cache'),
-            data_folder(''))
-        uri = path_to_uri(data_folder('song1.mp3'))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('blank_tag_cache'),
+            path_to_data_dir(''))
+        uri = path_to_uri(path_to_data_dir('song1.mp3'))
         self.assertEqual(set([Track(uri=uri, length=4000)]), tracks)
 
     def test_musicbrainz_tagcache(self):
-        tracks = parse_mpd_tag_cache(data_folder('musicbrainz_tag_cache'),
-            data_folder(''))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('musicbrainz_tag_cache'),
+            path_to_data_dir(''))
         artist = list(expected_tracks[0].artists)[0].copy(
             musicbrainz_id='7364dea6-ca9a-48e3-be01-b44ad0d19897')
         albumartist = list(expected_tracks[0].artists)[0].copy(
@@ -153,9 +153,9 @@ class MPDTagCacheToTracksTest(unittest.TestCase):
         self.assertEqual(track, list(tracks)[0])
 
     def test_albumartist_tag_cache(self):
-        tracks = parse_mpd_tag_cache(data_folder('albumartist_tag_cache'),
-            data_folder(''))
-        uri = path_to_uri(data_folder('song1.mp3'))
+        tracks = parse_mpd_tag_cache(path_to_data_dir('albumartist_tag_cache'),
+            path_to_data_dir(''))
+        uri = path_to_uri(path_to_data_dir('song1.mp3'))
         artist = Artist(name='albumartistname')
         album = expected_albums[0].copy(artists=[artist])
         track = Track(name='trackname', artists=expected_artists, track_no=1,
